==> huaweicloudsdkfunctiongraph-3.1.72-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/update_work_flow_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateWorkFlowRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workflow_id': 'str',
        'body': 'WorkflowCreateBody'
    }

    attribute_map = {
        'workflow_id': 'workflow_id',
        'body': 'body'
    }

    def __init__(self, workflow_id=None, body=None):
        """UpdateWorkFlowRequest

        The model defined in huaweicloud sdk

        :param workflow_id: 函数工作流ID
        :type workflow_id: str
        :param body: Body of the UpdateWorkFlowRequest
        :type body: :class:`huaweicloudsdkfunctiongraph.v2.WorkflowCreateBody`
        """
        
        

        self._workflow_id = None
        self._body = None
        self.discriminator = None

        self.workflow_id = workflow_id
        if body is not None:
            self.body = body

    @property
    def workflow_id(self):
        """Gets the workflow_id of this UpdateWorkFlowRequest.

        函数工作流ID

        :return: The workflow_id of this UpdateWorkFlowRequest.
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this UpdateWorkFlowRequest.

        函数工作流ID

        :param workflow_id: The workflow_id of this UpdateWorkFlowRequest.
        :type workflow_id: str
        """
        self._workflow_id = workflow_id

    @property
    def body(self):
        """Gets the body of this UpdateWorkFlowRequest.

        :return: The body of this UpdateWorkFlowRequest.
        :rtype: :class:`huaweicloudsdkfunctiongraph.v2.WorkflowCreateBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateWorkFlowRequest.

        :param body: The body of this UpdateWorkFlowRequest.
        :type body: :class:`huaweicloudsdkfunctiongraph.v2.WorkflowCreateBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWorkFlowRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfunctiongraph-3.1.145-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/update_work_flow_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateWorkFlowRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workflow_id': 'str',
        'body': 'WorkflowCreateBody'
    }

    attribute_map = {
        'workflow_id': 'workflow_id',
        'body': 'body'
    }

    def __init__(self, workflow_id=None, body=None):
        r"""UpdateWorkFlowRequest

        The model defined in huaweicloud sdk

        :param workflow_id: 函数工作流ID
        :type workflow_id: str
        :param body: Body of the UpdateWorkFlowRequest
        :type body: :class:`huaweicloudsdkfunctiongraph.v2.WorkflowCreateBody`
        """
        
        

        self._workflow_id = None
        self._body = None
        self.discriminator = None

        self.workflow_id = workflow_id
        if body is not None:
            self.body = body

    @property
    def workflow_id(self):
        r"""Gets the workflow_id of this UpdateWorkFlowRequest.

        函数工作流ID

        :return: The workflow_id of this UpdateWorkFlowRequest.
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        r"""Sets the workflow_id of this UpdateWorkFlowRequest.

        函数工作流ID

        :param workflow_id: The workflow_id of this UpdateWorkFlowRequest.
        :type workflow_id: str
        """
        self._workflow_id = workflow_id

    @property
    def body(self):
        r"""Gets the body of this UpdateWorkFlowRequest.

        :return: The body of this UpdateWorkFlowRequest.
        :rtype: :class:`huaweicloudsdkfunctiongraph.v2.WorkflowCreateBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateWorkFlowRequest.

        :param body: The body of this UpdateWorkFlowRequest.
        :type body: :class:`huaweicloudsdkfunctiongraph.v2.WorkflowCreateBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWorkFlowRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
